@@ -1,8 +1,5 @@
 import { parseRaw, TransparentState } from "../../modes/transparent";
-import {
-    RECEIVE as RECEIVE_STATE,
-    UPDATE as UPDATE_STATE,
-} from "../backendState";
+import { STATE_RECEIVE, STATE_UPDATE } from "../backendState";
 import { addSetter, createModeUpdateThunk, updateState } from "./utils";
 import { createSlice } from "@reduxjs/toolkit";
 
@@ -31,8 +28,8 @@ export const transparentSlice = createSlice({
         addSetter(builder, "active", setActive);
         addSetter(builder, "listen_host", setListenHost);
         addSetter(builder, "listen_port", setListenPort);
-        builder.addCase(RECEIVE_STATE, updateState("transparent", parseRaw));
-        builder.addCase(UPDATE_STATE, updateState("transparent", parseRaw));
+        builder.addCase(STATE_RECEIVE, updateState("transparent", parseRaw));
+        builder.addCase(STATE_UPDATE, updateState("transparent", parseRaw));
     },
 });
 
